data = {
    "moons": [
        "41 Experimentation",
        "220 Assurance",
        "56 Vow",
        "61 March",
        "20 Adamance",
        "85 Rend",
        "7 Dine",
        "21 Offense",
        "8 Titan",
        "68 Artifice",
        "5 Embrion",
    ],
    "store": [
        "Walkie-talkie",
        "Flashlight",
        "Shovel",
        "Lockpicker",
        "Pro-flashlight",
        "Stun grenade",
        "Boombox",
        "TZP-Inhalant",
        "Zap gun",
        "Jetpack",
        "Extension ladder",
        "Radar-booster",
        "Spray paint",
        "Weed killer",
        "Belt bag",
    ],
    "vehicles": [
        "Cruiser",
    ],
    "scrap": [
        {
            "Apparatus": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.986842105263158
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.87463556851312
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.54249547920434
                },
                {
                    "moon_name": "61 March",
                    "chance": 0
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.669642857142857
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.015015015015015
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0156599552572707
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.595238095238095
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.635593220338983
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.149532710280374
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.847457627118644
                }

            ]
        },
        {
            "Shotgun": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00440528634361234
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00278551532033426
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00952380952380952
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0197044334975369
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.240963855421687
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0697674418604651
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0087719298245614
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.128390596745027
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0828500414250207
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0694006309148265
                }

            ]
        },
        {
            "Kitchen knife": [
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0246305418719212
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0433734939759036
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.27906976744186
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0753935376967688
                }

            ]
        },
        {
            "Hive": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.148648648648649
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.21608040201005
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.138996138996139
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.357142857142857
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.137096774193548
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.15625
                }

            ]
        },
        {
            "Sapsucker Egg": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0351758793969849
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.305019305019305
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0403225806451613
                }

            ]
        },
        {
            "Large axle": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.121396054628225
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0323974082073434
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0238549618320611
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0792996910401648
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0289017341040462
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00166805671392827
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.101841820151679
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0352716873212583
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0208894878706199
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0819009100101112
                }

            ]
        },
        {
            "V-type engine": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.136570561456753
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0431965442764579
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0238549618320611
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0741503604531411
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0385356454720617
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00166805671392827
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0866738894907909
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0381315538608198
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0202156334231806
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0808897876643074
                }

            ]
        },
        {
            "Plastic fish": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0182094081942337
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0107991360691145
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0286259541984733
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0288362512873326
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0308285163776493
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0133444537114262
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0303358613217768
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0152526215443279
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0107816711590297
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0283114256825076
                }

            ]
        },
        {
            "Metal sheet": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.133535660091047
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0248380129589633
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0152671755725191
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0854788877445932
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0154142581888247
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0704225352112676
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.101112234580384
                }

            ]
        },
        {
            "Laser pointer": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00606980273141123
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00863930885529158
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.00763358778625954
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00308959835221421
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.00770712909441233
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00417014178482068
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0108342361863489
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.00953288846520496
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.00673854447439353
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.00606673407482305
                }

            ]
        },
        {
            "Big bolt": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.121396054628225
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0637149028077754
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0295801526717557
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0916580844490216
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0298651252408478
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00333611342785655
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0964247020585049
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0448045757864633
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0175202156334232
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0667340748230536
                }

            ]
        },
        {
            "Bottles": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0288315629742033
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.119870410367171
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0515267175572519
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0690010298661174
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0655105973025048
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0383653044203503
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0498374864572048
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0314585319351764
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0107816711590297
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0525783619817998
                }

            ]
        },
        {
            "Ring": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00455235204855842
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0158465387823186
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0257387988560534
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0283018867924528
                }

            ]
        },
        {
            "Steering wheel": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0485584218512898
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0205183585313175
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0162213740458015
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0115606936416185
                }

            ]
        },
        {
            "Cookie mold pan": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00758725341426404
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0529157667386609
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0467557251908397
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0247167868177137
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0385356454720617
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.00650054171180932
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0525783619817998
                }

            ]
        },
        {
            "Egg beater": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0151745068285281
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0367170626349892
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0534351145038168
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0481695568400771
                }

            ]
        },
        {
            "Jar of pickles": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0151745068285281
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0215982721382289
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.025763358778626
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0192678227360308
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00333611342785655
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.00762631077216397
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0222371967654987
                }

            ]
        },
        {
            "Dust pan": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0485584218512898
                }

            ]
        },
        {
            "Airhorn": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00455235204855842
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0107991360691145
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.00954198473282443
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0350154479917611
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.01252408477842
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00667222685571309
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0162513542795233
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0228789323164919
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0262803234501348
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0232558139534884
                }

            ]
        },
        {
            "Clown horn": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00455235204855842
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0107991360691145
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0333969465648855
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0442842430484037
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.00867052023121387
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00667222685571309
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.019501625135428
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0152526215443279
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0208894878706199
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0182002022244692
                }

            ]
        },
        {
            "Cash register": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00455235204855842
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00323974082073434
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.00477099236641221
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00308959835221421
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.00674373795761079
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0133444537114262
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0175202156334232
                }

            ]
        },
        {
            "Candy": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00303490136570561
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00308959835221421
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0116763969974979
                }

            ]
        },
        {
            "Gold bar": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00151745068285281
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00411946446961895
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0215633423180593
                }

            ]
        },
        {
            "Yield sign": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00910470409711684
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0183585313174946
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0152671755725191
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0082389289392379
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0154142581888247
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0303358613217768
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0141557128412538
                }

            ]
        },
        {
            "Homemade flashbang": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0333839150227618
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0151187904967603
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0133587786259542
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0202312138728324
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0140845070422535
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.00857959961868446
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.00876010781671159
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.00910010111223458
                }

            ]
        },
        {
            "Gift": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0257966616084977
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0140388768898488
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0114503816793893
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0247167868177137
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0221579961464355
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0158465387823186
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0205850487540628
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0162059103908484
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0101078167115903
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0171890798786653
                }

            ]
        },
        {
            "Flask": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0637329286798179
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0129589632829374
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0286259541984733
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.043254376930999
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0289017341040462
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0433369447453954
                }

            ]
        },
        {
            "Easter egg": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00758725341426404
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0345572354211663
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0267175572519084
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0669412976313079
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0481695568400771
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0475396163469558
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.00162866449511401
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0205850487540628
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0128032345013477
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0525783619817998
                }

            ]
        },
        {
            "Archipelago Chest": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0455235204855842
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0269978401727862
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0238549618320611
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0411946446961895
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0394990366088632
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0517097581317765
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0895765472312704
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0433369447453954
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0619637750238322
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0471698113207547
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0657229524772497
                }

            ]
        },
        {
            "AP Apparatus - 41 Experimentation": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0910470409711684
                }

            ]
        },
        {
            "Toy cube": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0334773218142549
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0162213740458015
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0185375901132853
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0163776493256262
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0275229357798165
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.019501625135428
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0190657769304099
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0134770889487871
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0252780586450961
                }

            ]
        },
        {
            "Remote": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0140388768898488
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0181297709923664
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0164778578784758
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.023121387283237
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0162513542795233
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0283114256825076
                }

            ]
        },
        {
            "Toy robot": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00647948164146868
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.00572519083969466
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00205973223480947
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.00867052023121387
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0383653044203503
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.00975081256771398
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0333651096282174
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0431266846361186
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0434782608695652
                }

            ]
        },
        {
            "Magnifying glass": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0183585313174946
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0200381679389313
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00411946446961895
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0202312138728324
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0291909924937448
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0216684723726977
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0238322211630124
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0283018867924528
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0141557128412538
                }

            ]
        },
        {
            "Stop sign": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0367170626349892
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0381679389312977
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0298661174047374
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0385356454720617
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0292524377031419
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0283114256825076
                }

            ]
        },
        {
            "Tea kettle": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0345572354211663
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0381679389312977
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0247167868177137
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0308285163776493
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0208507089241034
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0260021668472373
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0285986653956149
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0202156334231806
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0232558139534884
                }

            ]
        },
        {
            "Mug": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0129589632829374
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.017175572519084
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0115606936416185
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.036697247706422
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0200190657769304
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.00673854447439353
                }

            ]
        },
        {
            "Red soda": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0129589632829374
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0114503816793893
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00205973223480947
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0115606936416185
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0216847372810676
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0362249761677788
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0134770889487871
                }

            ]
        },
        {
            "Old phone": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00755939524838013
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0066793893129771
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.00385356454720617
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0141784820683903
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.00866738894907909
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0209723546234509
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0168463611859838
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.00808897876643074
                }

            ]
        },
        {
            "Hairdryer": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00431965442764579
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0358632193494579
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0285986653956149
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0370619946091644
                }

            ]
        },
        {
            "Brush": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0280777537796976
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0438931297709924
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0443159922928709
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0208507089241034
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0295519542421354
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0107816711590297
                }

            ]
        },
        {
            "Bell": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0172786177105832
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0314885496183206
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.035645472061657
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0400333611342786
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0352716873212583
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0377358490566038
                }

            ]
        },
        {
            "Whoopie cushion": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0118790496760259
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0362595419847328
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0192678227360308
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.00162866449511401
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0247855100095329
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0289757412398922
                }

            ]
        },
        {
            "Comedy": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00539956803455724
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0442035029190992
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0108342361863489
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0409914204003813
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.034366576819407
                }

            ]
        },
        {
            "Tragedy": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00323974082073434
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0208507089241034
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0438512869399428
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0357142857142857
                }

            ]
        },
        {
            "Toilet paper": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0205183585313175
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0324427480916031
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0329557157569516
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0385356454720617
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0108423686405338
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.019501625135428
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.00762631077216397
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0134770889487871
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0455005055611729
                }

            ]
        },
        {
            "Control pad": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0161987041036717
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0114503816793893
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0113285272914521
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0154142581888247
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0275229357798165
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0433369447453954
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0141557128412538
                }

            ]
        },
        {
            "Plastic cup": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0205183585313175
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0209923664122137
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0278063851699279
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0154142581888247
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.02418682235196
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0205850487540628
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0181124880838894
                }

            ]
        },
        {
            "Garbage lid": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0334773218142549
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.025763358778626
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0205973223480947
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0183044315992293
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00583819849874896
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0335861321776815
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.00741239892183288
                }

            ]
        },
        {
            "Soccer ball": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0248380129589633
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0209923664122137
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0216271884654995
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0233527939949958
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0262803234501348
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0262891809908999
                }

            ]
        },
        {
            "Zed Dog": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00107991360691145
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.000954198473282443
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00102986611740474
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00166805671392827
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.00108342361863489
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.000673854447439353
                }

            ]
        },
        {
            "AP Apparatus - 220 Assurance": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0539956803455724
                }

            ]
        },
        {
            "Rubber Ducky": [
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0229007633587786
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0240847784200385
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0133444537114262
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0228789323164919
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0404312668463612
                }

            ]
        },
        {
            "Chemical jug": [
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0438931297709924
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0394990366088632
                }

            ]
        },
        {
            "AP Apparatus - 56 Vow": [
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0477099236641221
                }

            ]
        },
        {
            "AP Apparatus - 61 March": [
                {
                    "moon_name": "61 March",
                    "chance": 0.0566426364572606
                }

            ]
        },
        {
            "AP Apparatus - 20 Adamance": [
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0481695568400771
                }

            ]
        },
        {
            "Fancy lamp": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0408673894912427
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0257387988560534
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0357142857142857
                }

            ]
        },
        {
            "Golden cup": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0200166805671393
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0257387988560534
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0370619946091644
                }

            ]
        },
        {
            "Painting": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0467055879899917
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0324118207816969
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0417789757412399
                }

            ]
        },
        {
            "Toothpaste": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0200166805671393
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0343183984747378
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0283018867924528
                }

            ]
        },
        {
            "Pill bottle": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.00333611342785655
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0142993326978074
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0101078167115903
                }

            ]
        },
        {
            "Perfume bottle": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0233527939949958
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0133460438512869
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.00943396226415094
                }

            ]
        },
        {
            "Teeth": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0258548790658882
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0119176598049837
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0200190657769304
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0181940700808625
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0121334681496461
                }

            ]
        },
        {
            "Magic 7 ball": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0191826522101751
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0152526215443279
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0202156334231806
                }

            ]
        },
        {
            "Toy train": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0291909924937448
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.00650054171180932
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0148247978436658
                }

            ]
        },
        {
            "Clock": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0291909924937448
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.00650054171180932
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0262803234501348
                }

            ]
        },
        {
            "AP Apparatus - 85 Rend": [
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0500417014178482
                }

            ]
        },
        {
            "Hand": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.162866449511401
                }

            ]
        },
        {
            "Bone": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.128664495114007
                }

            ]
        },
        {
            "Ribcage": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.128664495114007
                }

            ]
        },
        {
            "Ear": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0667752442996743
                }

            ]
        },
        {
            "Foot": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.162866449511401
                }

            ]
        },
        {
            "Knee": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0895765472312704
                }

            ]
        },
        {
            "Heart": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.00977198697068404
                }

            ]
        },
        {
            "Tongue": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0521172638436482
                }

            ]
        },
        {
            "AP Apparatus - 7 Dine": [
                {
                    "moon_name": "7 Dine",
                    "chance": 0.10586319218241
                }

            ]
        },
        {
            "AP Apparatus - 21 Offense": [
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0541711809317443
                }

            ]
        },
        {
            "AP Apparatus - 8 Titan": [
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0524308865586273
                }

            ]
        },
        {
            "AP Apparatus - 68 Artifice": [
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0404312668463612
                }

            ]
        },
        {
            "AP Apparatus - 5 Embrion": [
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0606673407482305
                }

            ]
        },
    ],
    "bestiary": [
        {
            "Circuit bee": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.148648648648649
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.21608040201005
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.138996138996139
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.357142857142857
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.137096774193548
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.15625
                }

            ]
        },
        {
            "Manticoil": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.5
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.50251256281407
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.386100386100386
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.423469387755102
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.508064516129032
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 1
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.46875
                }

            ]
        },
        {
            "Roaming locust": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.351351351351351
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.231155778894472
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.154440154440154
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.198979591836735
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.241935483870968
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.348958333333333
                }

            ]
        },
        {
            "Eyeless dog": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.555555555555556
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.402061855670103
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0261437908496732
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.187192118226601
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.2
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.552238805970149
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.301204819277108
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.4739336492891
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.650406504065041
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.19
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0260869565217391
                }

            ]
        },
        {
            "Forest keeper": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00740740740740741
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00515463917525773
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.65359477124183
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.315270935960591
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.168421052631579
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.447761194029851
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.602409638554217
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.042654028436019
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.260162601626016
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.23
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0260869565217391
                }

            ]
        },
        {
            "Earth leviathan": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.414814814814815
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.489690721649485
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.117647058823529
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0788177339901478
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0631578947368421
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0180722891566265
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.175355450236967
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.032520325203252
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.06
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0782608695652174
                }

            ]
        },
        {
            "Old bird": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0222222222222222
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0210526315789474
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0783132530120482
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.023696682464455
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0569105691056911
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.45
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.869565217391304
                }

            ]
        },
        {
            "Snare flea": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.224669603524229
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.259052924791086
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.133333333333333
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.120634920634921
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.103448275862069
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0746987951807229
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0465116279069767
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.118421052631579
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0976491862567812
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0637945318972659
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0473186119873817
                }

            ]
        },
        {
            "Bunker spider": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.255506607929515
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.192200557103064
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.111111111111111
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.203174603174603
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.152709359605911
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.103614457831325
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0465116279069767
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.192982456140351
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.106690777576854
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0828500414250207
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0725552050473186
                }

            ]
        },
        {
            "Hoarding bug": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.123348017621145
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.217270194986072
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.175
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.114285714285714
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.140394088669951
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0813953488372093
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0701754385964912
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0687160940325497
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0787075393537697
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.271293375394322
                }

            ]
        },
        {
            "Bracken": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0572687224669604
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0389972144846797
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.222222222222222
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.177777777777778
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0985221674876847
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.12289156626506
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0581395348837209
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0131578947368421
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.112115732368897
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0828500414250207
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.00946372239747634
                }

            ]
        },
        {
            "Thumper": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.0704845814977974
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0668523676880223
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.025
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.234920634920635
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.165024630541872
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0348837209302326
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.241228070175439
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0976491862567812
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0762220381110191
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0946372239747634
                }

            ]
        },
        {
            "Hygrodere": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.136563876651982
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0779944289693593
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0777777777777778
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0476190476190476
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.041871921182266
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0144578313253012
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0232558139534884
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.140350877192982
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0361663652802893
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0604805302402651
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.132492113564669
                }

            ]
        },
        {
            "Spore lizard": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.123348017621145
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0389972144846797
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0527777777777778
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0285714285714286
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0812807881773399
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0168674698795181
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0348837209302326
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0307017543859649
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.0289330922242315
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0745650372825186
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.110410094637224
                }

            ]
        },
        {
            "Nutcracker": [
                {
                    "moon_name": "41 Experimentation",
                    "chance": 0.00440528634361234
                },
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00278551532033426
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.00952380952380952
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0197044334975369
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.240963855421687
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0697674418604651
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0087719298245614
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.128390596745027
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0828500414250207
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0694006309148265
                }

            ]
        },
        {
            "Tulip snake": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0150753768844221
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0154440154440154
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0204081632653061
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0725806451612903
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0260416666666667
                }

            ]
        },
        {
            "Giant Sapsucker": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0351758793969849
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.305019305019305
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0403225806451613
                }

            ]
        },
        {
            "Baboon hawk": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.103092783505155
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.202614379084967
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.41871921182266
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.547368421052632
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.28436018957346
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.07
                }

            ]
        },
        {
            "Barber": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.00835654596100279
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0388888888888889
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.00738916256157635
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0265060240963855
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.13953488372093
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0372825186412593
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.113564668769716
                }

            ]
        },
        {
            "Maneater": [
                {
                    "moon_name": "220 Assurance",
                    "chance": 0.0947075208913649
                },
                {
                    "moon_name": "56 Vow",
                    "chance": 0.147222222222222
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0285714285714286
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.105911330049261
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0232558139534884
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.0745614035087719
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0347970173985087
                }

            ]
        },
        {
            "Coil-head": [
                {
                    "moon_name": "56 Vow",
                    "chance": 0.0166666666666667
                },
                {
                    "moon_name": "61 March",
                    "chance": 0.0317460317460317
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0246305418719212
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.103614457831325
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0581395348837209
                },
                {
                    "moon_name": "21 Offense",
                    "chance": 0.109649122807018
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.106690777576854
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0712510356255178
                },
                {
                    "moon_name": "5 Embrion",
                    "chance": 0.0788643533123028
                }

            ]
        },
        {
            "Jester": [
                {
                    "moon_name": "61 March",
                    "chance": 0.00317460317460317
                },
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0172413793103448
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.144578313253012
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.0697674418604651
                },
                {
                    "moon_name": "8 Titan",
                    "chance": 0.128390596745027
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0762220381110191
                }

            ]
        },
        {
            "Butler": [
                {
                    "moon_name": "20 Adamance",
                    "chance": 0.0246305418719212
                },
                {
                    "moon_name": "85 Rend",
                    "chance": 0.0433734939759036
                },
                {
                    "moon_name": "7 Dine",
                    "chance": 0.27906976744186
                },
                {
                    "moon_name": "68 Artifice",
                    "chance": 0.0753935376967688
                }

            ]
        },
    ]
}